@@ -1,12 +1,10 @@
-import os.path
-from tempfile import TemporaryDirectory
-
 import pytest
 
 from ocdskit.cli.__main__ import main
-from tests import assert_command, path, run_command
+from tests import assert_command, assert_command_error, path, run_command
 
-test_command_argvalues = [
+
+@pytest.mark.parametrize('filename,result', [
     ('record-package_minimal.json', 'record package'),
     ('release-package_minimal.json', 'release package'),
     ('record_minimal.json', 'record'),
@@ -17,9 +15,41 @@ test_command_argvalues = [
     ('release-packages.jsonl', 'concatenated JSON, starting with a JSON array of release packages'),
     ('detect-format_mixed.json', 'concatenated JSON, starting with release'),
     ('detect-format_whitespace.json', 'release'),
-]
+])
+def test_command(filename, result, monkeypatch):
+    expected = 'tests/fixtures/{}: {}\n'.format(filename, result)
+    assert_command(monkeypatch, main, ['detect-format', path(filename)], expected)
 
-test_command_unknown_format_argvalues = [
+
+@pytest.mark.parametrize('filename,root_path,result', [
+    ('record-package_minimal.json', 'records', 'a JSON array of records'),
+    ('record-package_minimal.json', 'records.item', 'record'),
+])
+def test_command_root_path(filename, root_path, result, monkeypatch):
+    expected = 'tests/fixtures/{}: {}\n'.format(filename, result)
+    assert_command(monkeypatch, main, ['detect-format', '--root-path', root_path, path(filename)], expected)
+
+
+def test_command_root_path_nonexistent(monkeypatch, caplog):
+    assert_command_error(monkeypatch, main, ['detect-format', '--root-path', 'nonexistent',
+                                             path('record_minimal.json')], error=StopIteration)
+
+    assert len(caplog.records) == 0
+
+
+def test_command_recursive(monkeypatch, caplog, tmpdir):
+    content = b'{"records":[]}'
+    tmpdir.join('test.json').write(content)
+    tmpdir.join('.test.json').write(content)
+
+    actual = run_command(monkeypatch, main, ['detect-format', '--recursive', str(tmpdir)])
+
+    assert '/test.json: record package' in actual
+    assert '.test.json' not in actual
+    assert len(caplog.records) == 0
+
+
+@pytest.mark.parametrize('basename,result', [
     ('false', 'boolean'),
     ('null', 'null'),
     ('number', 'number'),
@@ -27,33 +57,7 @@ test_command_unknown_format_argvalues = [
     ('true', 'boolean'),
     ('array', 'non-OCDS array'),
     ('object', 'non-OCDS object'),
-]
-
-content = b'{"records":[]}'
-
-
-@pytest.mark.parametrize('filename,result', test_command_argvalues)
-def test_command(filename, result, monkeypatch):
-    expected = 'tests/fixtures/{}: {}\n'.format(filename, result)
-    assert_command(monkeypatch, main, ['detect-format', path(filename)], expected)
-
-
-def test_command_recursive(monkeypatch, caplog):
-    with TemporaryDirectory() as d:
-        with open(os.path.join(d, 'test.json'), 'wb') as f:
-            f.write(content)
-
-        with open(os.path.join(d, '.test.json'), 'wb') as f:
-            f.write(content)
-
-        actual = run_command(monkeypatch, main, ['detect-format', '--recursive', d])
-
-        assert '/test.json: record package' in actual
-        assert '.test.json' not in actual
-        assert len(caplog.records) == 0
-
-
-@pytest.mark.parametrize('basename,result', test_command_unknown_format_argvalues)
+])
 def test_command_unknown_format(basename, result, monkeypatch, caplog):
     filename = 'detect-format_{}.json'.format(basename)
 
@@ -65,13 +69,12 @@ def test_command_unknown_format(basename, result, monkeypatch, caplog):
         filename, result)
 
 
-def test_command_directory(monkeypatch, caplog):
-    with TemporaryDirectory() as d:
-        assert_command(monkeypatch, main, ['detect-format', d], '')
+def test_command_directory(monkeypatch, caplog, tmpdir):
+    assert_command(monkeypatch, main, ['detect-format', str(tmpdir)], '')
 
-        assert len(caplog.records) == 1
-        assert caplog.records[0].levelname == 'WARNING'
-        assert caplog.records[0].message.endswith(' is a directory. Set --recursive to recurse into directories.')
+    assert len(caplog.records) == 1
+    assert caplog.records[0].levelname == 'WARNING'
+    assert caplog.records[0].message.endswith(' is a directory. Set --recursive to recurse into directories.')
 
 
 def test_command_nonexistent(monkeypatch, caplog):
