@@ -1,9 +1,8 @@
 import json
-from tempfile import TemporaryFile
 
 import pytest
 
-from ocdskit.util import is_linked_release, is_record, json_dump
+from ocdskit.util import is_compiled_release, is_linked_release, is_record, json_dump
 from tests import read
 
 
@@ -32,14 +31,24 @@ def test_is_linked_release(data, expected):
     assert is_linked_release(data) == expected
 
 
+@pytest.mark.parametrize('data,expected', [
+    ({'url': 'http://example.com', 'date': '2001-02-03T04:05:06Z', 'tag': ['compiled']}, True),
+    ({'url': 'http://example.com', 'date': '2001-02-03T04:05:06Z', 'tag': ['tender']}, False),
+    ({'url': 'http://example.com', 'date': '2001-02-03T04:05:06Z', 'tag': None}, False),
+    ({'url': 'http://example.com', 'date': '2001-02-03T04:05:06Z'}, False),
+])
+def test_is_compiled_release(data, expected):
+    assert is_compiled_release(data) == expected
+
+
 @pytest.mark.parametrize('data,expected', [
     (iter([]), '[]'),
     ({'a': 1, 'b': 2}, '{"a":1,"b":2}'),
 ])
-def test_json_dump(data, expected):
-    with TemporaryFile('w+') as f:
+def test_json_dump(data, expected, tmpdir):
+    p = tmpdir.join('test.json')
+
+    with open(p, 'w') as f:
         json_dump(data, f)
 
-        f.seek(0)
-
-        assert f.read() == expected
+    assert p.read() == expected
